@@ -177,7 +177,8 @@ class TestGeneralUsage:
         assert result.ret != 0
         assert "should be seen" in result.stdout.str()
 
-    @pytest.mark.skipif("not hasattr(py.path.local, 'mksymlinkto')")
+    @pytest.mark.skipif(not hasattr(py.path.local, 'mksymlinkto'),
+                        reason="symlink not available on this platform")
     def test_chdir(self, testdir):
         testdir.tmpdir.join("py").mksymlinkto(py._pydir)
         p = testdir.tmpdir.join("main.py")
@@ -307,7 +308,15 @@ class TestGeneralUsage:
                 '*ERROR*',
             ])
             assert result.ret == 4  # usage error only if item not found
-    
+
+    def test_report_all_failed_collections_initargs(self, testdir):
+        testdir.makepyfile(test_a="def", test_b="def")
+        result = testdir.runpytest("test_a.py::a", "test_b.py::b")
+        result.stderr.fnmatch_lines([
+            "*ERROR*test_a.py::a*",
+            "*ERROR*test_b.py::b*",
+        ])
+
     def test_namespace_import_doesnt_confuse_import_hook(self, testdir):
         # Ref #383. Python 3.3's namespace package messed with our import hooks
         # Importing a module that didn't exist, even if the ImportError was
@@ -319,7 +328,7 @@ class TestGeneralUsage:
             except ImportError:
                 # We handle the import error gracefully here
                 pass
-            
+
             def test_whatever():
                 pass
         """)
